@@ -1,9 +1,6 @@
 
-/* pdlapi.c - functions for manipulating pdl structs  */
-/*  - for a while (up to + including 2.2.1) this file */
-/*    created by pdlapi.c.PL [due to bad value code]  */
-/*    we now have dummy functions so do not need to   */
-/*    create the file                                 */
+/* pdlapi.c - functions for manipulating pdl structs */
+
 
 #define PDL_CORE      /* For certain ifdefs */
 #include "pdl.h"      /* Data structure declarations */
@@ -210,11 +207,7 @@ void pdl__destroy_childtranses(pdl *it,int ensure) {
 	PDL_END_CHILDLOOP(it)
 }
 
-/*
-
-  *Note*: the mutator/progenitor/family stuff is disabled and will
-  be ignored for the foreseeable future.
-
+/* Must think about.
   A piddle may be
    - a parent of something - just ensure & destroy
    - a child of something - just ensure & destroy
@@ -258,20 +251,11 @@ void pdl_destroy(pdl *it) {
 	    it->sv = NULL;
     }
 
-    /* the progenitor etc stuff is not really implemented
-       so we comment it out; this should not affect anything
-       -- we'll see ;)
-       Note: the memleak comment refers to the original code
-       which is now disabled!
-    */
-    /* XXXXXXXXX Shouldn't do this! BAD MEMLEAK */
-    /* 
-       if(it->progenitor || it->living_for || it->future_me) {
-           PDLDEBUG_f(printf("Family, not Destr. %d\n",it);)
-           goto soft_destroy;
-       }
-    */
-
+    if(it->progenitor || it->living_for || it->future_me) {
+    	/* XXXXXXXXX Shouldn't do this! BAD MEMLEAK */
+        PDLDEBUG_f(printf("Family, not Destr. %d\n",it);)
+	goto soft_destroy;
+    }
     /* 1. count the children that do flow */
     PDL_START_CHILDLOOP(it)
     	curt = PDL_CHILDLOOP_THISCHILD(it);
@@ -433,25 +417,16 @@ void pdl_dump_flags(int flags, int nspac)
 {
 	int i;
 	int len, found, sz;
-
-	int flagval[15] = {
-	    PDL_ALLOCATED,PDL_PARENTDATACHANGED,
-	    PDL_PARENTDIMSCHANGED,PDL_PARENTREPRCHANGED,
-	    PDL_DATAFLOW_F,PDL_DATAFLOW_B,PDL_NOMYDIMS,
-	    PDL_OPT_VAFFTRANSOK,PDL_INPLACE,PDL_DESTROYING,
-	    PDL_DONTTOUCHDATA, PDL_MYDIMS_TRANS, PDL_HDRCPY, 
-	    PDL_BADVAL, 0
-	};
-
-	char *flagchar[14] = {
-	    "ALLOCATED","PARENTDATACHANGED",
-	    "PARENTDIMSCHANGED","PARENTREPRCHANGED",
-	    "DATAFLOW_F","DATAFLOW_B","NOMYDIMS",
-	    "OPT_VAFFTRANSOK","INPLACE","DESTROYING",
-	    "DONTTOUCHDATA","MYDIMS_TRANS", "HDRCPY",
-            "BADVAL"
-	};
-
+	int flagval[14] = {PDL_ALLOCATED,PDL_PARENTDATACHANGED,
+			 PDL_PARENTDIMSCHANGED,PDL_PARENTREPRCHANGED,
+			 PDL_DATAFLOW_F,PDL_DATAFLOW_B,PDL_NOMYDIMS,
+			 PDL_OPT_VAFFTRANSOK,PDL_INPLACE,PDL_DESTROYING,
+			 PDL_DONTTOUCHDATA, PDL_MYDIMS_TRANS, PDL_HDRCPY, 0};
+	char *flagchar[13] = {"ALLOCATED","PARENTDATACHANGED",
+			 "PARENTDIMSCHANGED","PARENTREPRCHANGED",
+			 "DATAFLOW_F","DATAFLOW_B","NOMYDIMS",
+			 "OPT_VAFFTRANSOK","INPLACE","DESTROYING",
+			 "DONTTOUCHDATA","MYDIMS_TRANS", "HDRCPY"};
 	char *spaces = malloc(nspac+1); for(i=0; i<nspac; i++) spaces[i]=' ';
 	spaces[i] = '\0';
 
@@ -477,7 +452,7 @@ void pdl_dump_spac(pdl *it,int nspac)
 	spaces[i] = '\0';
 	printf("%sDUMPING %d     datatype: %d\n",spaces,it,it->datatype);
 	pdl_dump_flags(it->state,nspac+3);
-	printf("%s   transvtable: %d, trans: %d, sv: %d\n",spaces,
+	printf("%s   transv: %d, trans: %d, sv: %d\n",spaces,
 		(it->trans?it->trans->vtable:0), it->trans, it->sv);
 	if(it->datasv) {
 		printf("%s   Data SV: %d, Svlen: %d, data: %d, nvals: %d\n", spaces,
@@ -625,14 +600,12 @@ void pdl_print(pdl *it) {
 #endif
 }
 
-/* pdl_get is now vaffine aware */
 double pdl_get(pdl *it,int *inds) {
-        int i, *incs;
-        int offs=PDL_REPROFFS(it);
-        incs = PDL_VAFFOK(it) ? it->vafftrans->incs : it->dimincs;
-        for(i=0; i<it->ndims; i++)
-                offs += incs[i] * inds[i];
-        return pdl_get_offs(PDL_REPRP(it),offs);
+	int i;
+	int offs=0;
+	for(i=0; i<it->ndims; i++)
+		offs += it->dimincs[i] * inds[i];
+	return pdl_get_offs(it,offs);
 }
 
 double pdl_get_offs(pdl *it, PDL_Long offs) {
@@ -716,18 +689,10 @@ void pdl_make_physdims(pdl *it) {
 	  return;
 	}
 	it->state &= ~(PDL_PARENTDIMSCHANGED | PDL_PARENTREPRCHANGED);
-	/* the fact that a PARENTXXXCHANGED flag is set seems
-	   to imply that this pdl has an associated trans ? */
 	for(i=0; i<it->trans->vtable->nparents; i++) {
 		pdl_make_physdims(it->trans->pdls[i]);
 	}
-	/* doesn't this mean that all children of this trans have
-	   now their dims set and accordingly all those flags should
-	   be reset? Otherwise redodims will be called for them again? */
-	PDLDEBUG_f(printf("Make_physdims: calling redodims %d on %d\n",
-			  it->trans,it));
 	it->trans->vtable->redodims(it->trans);
-	/* why this one? will the old allocated data be freed correctly? */
 	if((c & PDL_PARENTDIMSCHANGED) && (it->state & PDL_ALLOCATED)) {
 		it->state &= ~PDL_ALLOCATED;
 	}
@@ -766,7 +731,7 @@ void pdl_set_trans_parenttrans(pdl *it, pdl_trans *trans,int nth)
 		for(i=0; i<trans->vtable->nparents; i++)
 			if(trans->pdls[i] == it) nthind = i;
 		croak("Sorry, families not allowed now (i.e. You cannot modify dataflowing pdl)\n");
-		/* pdl_family_create(it,trans,nthind,nth); */
+		pdl_family_create(it,trans,nthind,nth);
 	} else {
 		it->trans = trans;
 		it->state |= PDL_PARENTDIMSCHANGED | PDL_PARENTDATACHANGED ;
@@ -866,7 +831,7 @@ void pdl_make_trans_mutual(pdl_trans *trans)
 		pdl_set_trans_childtrans(trans->pdls[i],trans,i);
 	  for(i=trans->vtable->nparents; i<trans->vtable->npdls; i++)
 		pdl_set_trans_parenttrans(trans->pdls[i],trans,i);
-	  if(!(trans->flags & PDL_ITRANS_REVERSIBLE))
+	  if(!(trans->flags&PDL_ITRANS_REVERSIBLE))
 		trans->flags &= ~PDL_ITRANS_DO_DATAFLOW_B;
 	  for(i=trans->vtable->nparents; i<trans->vtable->npdls; i++) {
 	  	if(trans->pdls[i]->state & PDL_NOMYDIMS) {
@@ -876,6 +841,7 @@ void pdl_make_trans_mutual(pdl_trans *trans)
 	  }
   }
 
+
 #ifdef FOO
 /* If we are not flowing, we must disappear */
   if(!(trans->flags & PDL_ITRANS_DO_DATAFLOW_ANY)) {
@@ -885,21 +851,17 @@ void pdl_make_trans_mutual(pdl_trans *trans)
 
   PDLDEBUG_f(printf("make_trans_mutual_exit %d\n",trans));
 
-} /* pdl_make_trans_mutual() */
+}
 
 
 pdl *pdl_make_now(pdl *it) {
-  return it;
-  /* the family stuff is not really implemented
-     so we'll ignore it and get rid of pdlfamily.c
 	if(it->future_me) return it->future_me;
 	if(!it->progenitor) return it;
 	return pdl_family_clone2now(it);
-  */
 }
 
 void pdl_make_physical(pdl *it) {
-	int i, vaffinepar=0;
+	int i;
 	DECL_RECURSE_GUARD;
 
 	PDLDEBUG_f(printf("Make_physical %d\n",it));
@@ -936,38 +898,14 @@ void pdl_make_physical(pdl *it) {
 #ifndef DONT_OPTIMIZE
 #ifndef DONT_VAFFINE
 		if(it->trans->vtable->per_pdl_flags[i] &
-		    PDL_TPDL_VAFFINE_OK) {
+		    PDL_TPDL_VAFFINE_OK)
 		    	pdl_make_physvaffine(it->trans->pdls[i]);
-                        /* check if any of the parents is a vaffine */
-                        vaffinepar = vaffinepar || (it->trans->pdls[i]->data != PDL_REPRP(it->trans->pdls[i]));
-                }  
 		else
 #endif
 #endif
 			pdl_make_physical(it->trans->pdls[i]);
 	}
-        /* the next one is really strange:
-         *
-         * why do we need to call redodims if   !(it->state & PDL_ALLOCATED)   ???
-         * this results in a) redodims called twice if make_physdims had already been
-         * called for this piddle and results in associated memory leaks!
-         * On the other hand, if I comment out  !(it->state & PDL_ALLOCATED)
-         * then we get errors for cases like 
-         *                  $in = $lut->xchg(0,1)->index($im->dummy(0));
-         *                  $in .= pdl -5;
-         * Currently ugly fix: detect in initthreadstruct that it has been called before
-         * and free all pdl_thread related memory before reallocating
-         * NOTE: this does not catch leaks when additional memory was allocated from with
-         *       redodims!!!!!
-         *
-         * The real question is: why do we need another call to
-         * redodims if !(it->state & PDL_ALLOCATED)??????
-         * changed it so that redodims only called if
-         *            (!(it->state & PDL_ALLOCATED) && vaffinepar)
-         * i.e. at least one of the parent piddles is a real vaffine
-         * CS
-         */
-	if((!(it->state & PDL_ALLOCATED) && vaffinepar) ||
+	if(!(it->state & PDL_ALLOCATED) ||
 	   it->state & PDL_PARENTDIMSCHANGED ||
 	   it->state & PDL_PARENTREPRCHANGED) {
 		it->trans->vtable->redodims(it->trans);
@@ -1167,7 +1105,7 @@ void pdl__ensure_trans(pdl_trans *trans,int what)
 		}
 		flag |= trans->pdls[j]->state & PDL_ANYCHANGED;
 	}
-	if(flag & PDL_PARENTDIMSCHANGED) {  /* redodims called here... */
+	if(flag & PDL_PARENTDIMSCHANGED) {
 		trans->vtable->redodims(trans);
 	}
 	for(j=0; j<trans->vtable->npdls; j++) {
@@ -1177,11 +1115,7 @@ void pdl__ensure_trans(pdl_trans *trans,int what)
 	if(flag & PDL_PARENTDATACHANGED | flag & PDL_PARENTDIMSCHANGED) {
 		int i;
 		if(par_pvaf && (trans->flags & PDL_ITRANS_ISAFFINE)) {
-		  /* Attention: this assumes affine = p2child */
-		  /* need to signal that redodims has already been called */
-		  /* is it correct to also unset PDL_PARENTREPRCHANGED? */
-		        trans->pdls[1]->state &= ~(PDL_PARENTDIMSCHANGED |
-						  PDL_PARENTREPRCHANGED);
+			/* Assuming affine = p2child */
 			pdl_make_physvaffine(trans->pdls[1]);
 			pdl_readdata_vaffine(trans->pdls[1]);
 		} else {
@@ -1216,9 +1150,6 @@ void pdl__ensure_transdims(pdl_trans *trans)
    We shall ignore this problem for now and hope it goes away ;)
    (XXX FIX ME) */
 /* XXX Two next routines are memleaks */
-/* somehow this transform will call (implicitly) redodims twice on
-   an unvaffined pdl; leads to memleak if redodims allocates stuff
-   that is only freed in later call to freefunc */
 void pdl_destroytransform(pdl_trans *trans,int ensure)
 {
 	int j;
@@ -1354,16 +1285,6 @@ void pdl_vafftrans_free(pdl *it)
  * We need to do careful testing for clump-type things.
  */
 
-/* pdl_make_physvaffine can be called on *any* pdl -- vaffine or not --
-   it will call make_physical as needed on those
-   this function is the right one to call in any case if you want to
-   make only those physical (i.e. allocating their own data, etc) which
-   have to be and leave those vaffine with updated dims, etc, that do
-   have an appropriate transformation of which they are a child
-
-   should probably have been called make_physcareful to point out what
-   it really does
-*/
 void pdl_make_physvaffine(pdl *it)
 {
 	pdl_trans *t;
@@ -1392,8 +1313,7 @@ void pdl_make_physvaffine(pdl *it)
 	}
 	PDL_ENSURE_VAFFTRANS(it);
 	incsleft = malloc(sizeof(*incsleft)*it->ndims);
-        PDLDEBUG_f(printf("vaff_malloc: got %d\n",incsleft));
-        for(i=0; i<it->ndims; i++) {
+	for(i=0; i<it->ndims; i++) {
 		it->vafftrans->incs[i] = it->dimincs[i];
 	}
 
@@ -1479,8 +1399,7 @@ void pdl_make_physvaffine(pdl *it)
 	pdl_make_physical(current);
 
   mkphys_vaff_end:
-       PDLDEBUG_f(printf("vaff_malloc: %d\n",incsleft));
-       if (incsleft != NULL) free(incsleft);
+       free(incsleft);
 	PDLDEBUG_f(printf("Make_physvaffine_exit %d\n",it));
 
 }
