@@ -50,7 +50,6 @@ actnw q|
 	$g = cos($cz*6.3)/2 + 0.5;
 	$b = $cz;
 	line3d [$cx,$cy,$cz], [$r,$g,$b];    # Draw a colored line
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
@@ -58,7 +57,6 @@ actnw q|
 	$y = (yvals zeroes $size+1,$size+1) / $size;
 	$z = 0.5 + 0.5 * (sin($x*6.3) * sin($y*6.3)) ** 3;   # Bumps
 	line3d [$x,$y,$z];	# Draw several lines
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
@@ -66,40 +64,33 @@ actnw q|
 	$g = $y;
 	$b = $z;
 	line3d [$x,$y,$z], [$r,$g,$b];	# Draw several colored lines
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	lattice3d [$x,$y,$z], [$r,$g,$b];  # Draw a colored lattice
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
-	points3d [$x,$y,$z], [$r,$g,$b], {PointSize=>4};  # Draw colored points
-	# [press 'q' in the graphics window when done]
+	points3d [$x,$y,$z], [$r,$g,$b];  # Draw colored points
 |;
 
 actnw q|
 	imag3d_ns [$x,$y,$z], [$r,$g,$b];  # Draw a colored surface
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	imag3d [$x,$y,$z]; # Draw a shaded surface
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	hold3d();	# Leave the previous object in..
 	imag3d_ns [$x,$y,$z+1], [$r,$g,$b];
 			# ...and draw a colored surface on top of it...
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	lattice3d [$x,$y,$z-1], [$r,$g,$b];
 			# ...and draw a colored lattice under it...
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
@@ -110,7 +101,6 @@ actnw q|
 	keeptwiddling3d();   # Do wait for user while drawing...
 	twiddle3d();	     # and actually, wait right now.
 	release3d();
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
@@ -122,13 +112,11 @@ actnw q|
 	$colors = $coords;
 	line3d $coords, $colors;        # Draw a curved line, colored
 					# (this works also for lattices, etc.)
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	# 2. You can use defaults inside the brackets:
 	lattice3d [$z], [$r];  # Note: no $x, $y, and $r is greyscale
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
@@ -136,13 +124,11 @@ actnw q|
 	imag3d_ns [POLAR2D, $z], [$r, $g, $b];  # Draw the familiar
 						# bumpy surface in polar
 						# coordinates
-	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	# One last thing: you can plot a color image like this
 	imagrgb([$r,$g,$b]);
-	# [press 'q' in the graphics window when done]
 |;
 
 comment q|
